@@ -152,7 +152,7 @@ ReductiveHourglassTest <- function(ExpressionSet,
         score_vector <- vector(mode = "numeric",length = permutations)
         resMatrix <- matrix(NA_real_, permutations,(nCols-2))
         real_age <- vector(mode = "numeric",length = nCols-2)
-        real_age <- cpp_TAI(as.matrix(ExpressionSet[ , 3:nCols]),as.vector(ExpressionSet[ , 1]))
+        real_age <- cpp_TAI(as.matrix(dplyr::select(ExpressionSet, 3:ncol(ExpressionSet))),as.vector(unlist(dplyr::select(ExpressionSet, 1))))
         ### compute the real reductive hourglass scores of the observed phylotranscriptomics pattern
         real_score <- rhScore(real_age,
                               early         = modules[[1]],
@@ -163,12 +163,12 @@ ReductiveHourglassTest <- function(ExpressionSet,
         
         ### compute the bootstrap matrix 
         if (is.null(custom.perm.matrix)){
-                resMatrix <- cpp_bootMatrix(as.matrix(ExpressionSet[ , 3:nCols]),
-                                            as.vector(ExpressionSet[ , 1]),
+                resMatrix <- cpp_bootMatrix(as.matrix(dplyr::select(ExpressionSet, 3:ncol(ExpressionSet))),
+                                            as.vector(unlist(dplyr::select(ExpressionSet, 1))),
                                             as.numeric(permutations))       
         }
         
-        else if (!is.null(custom.perm.matrix)){
+        else if (!is.null(custom.perm.matrix)) {
                 resMatrix <- custom.perm.matrix
         }
         
