@@ -44,13 +44,13 @@ TAI <- function(PhyloExpressionSet)
         is.ExpressionSet(PhyloExpressionSet)
         
         nCols <- dim(PhyloExpressionSet)[2]
-        ExpressionMatrix <- PhyloExpressionSet[ , 3:nCols]
-        Phylostratum <- PhyloExpressionSet[ , 1]
-        TAIProfile <- vector(mode = "numeric",length = nCols-2)
+        ExpressionMatrix <- dplyr::select(PhyloExpressionSet, 3:ncol(PhyloExpressionSet))
+        Phylostratum <- unlist(dplyr::select(PhyloExpressionSet, 1))
+        TAIProfile <- vector(mode = "numeric", length = nCols - 2)
         
-        TAIProfile <- cpp_TAI(as.matrix(ExpressionMatrix),as.vector(Phylostratum))
+        TAIProfile <- cpp_TAI(as.matrix(ExpressionMatrix), as.vector(Phylostratum))
         names(TAIProfile) <- names(ExpressionMatrix)
         
         return(TAIProfile)
         
-}
\ No newline at end of file
+}
