@@ -38,14 +38,14 @@ TDI <- function(DivergenceExpressionSet)
         is.ExpressionSet(DivergenceExpressionSet)
         
         nCols <- dim(DivergenceExpressionSet)[2]
-        ExpressionMatrix <- DivergenceExpressionSet[ , 3:nCols]
-        Divergencestratum <- DivergenceExpressionSet[ , 1]
-        TDIProfile <- vector(mode = "numeric",length = nCols-2)
+        ExpressionMatrix <- dplyr::select(DivergenceExpressionSet, 3:ncol(DivergenceExpressionSet))
+        Divergencestratum <- unlist(dplyr::select(DivergenceExpressionSet, 1))
+        TDIProfile <- vector(mode = "numeric", length = nCols - 2)
         
         
-        TDIProfile <- cpp_TAI(as.matrix(ExpressionMatrix),as.vector(Divergencestratum))
+        TDIProfile <- cpp_TAI(as.matrix(ExpressionMatrix), as.vector(Divergencestratum))
         names(TDIProfile) <- names(ExpressionMatrix)
         
         return(TDIProfile)
         
-}
\ No newline at end of file
+}
